@@ -1,4 +1,4 @@
 from todoman.cli import cli
 
 if __name__ == '__main__':
-    cli()
+    cli(auto_envvar_prefix='TODOMAN')
