@@ -256,13 +256,21 @@ _interactive_option = click.option(
     is_flag=True,
     help='Format all dates and times in a human friendly way'
 )
+@click.option(
+    '--config',
+    '-c',
+    default=None,
+    help='The config file to use.',
+    envvar='TODOMAN_CONFIG',
+    metavar='PATH',
+)
 @click.pass_context
 @click.version_option(prog_name='todoman')
 @catch_errors
-def cli(click_ctx, colour, porcelain, humanize):
+def cli(click_ctx, colour, porcelain, humanize, config):
     ctx = click_ctx.ensure_object(AppContext)
     try:
-        ctx.config = load_config()
+        ctx.config = load_config(config)
     except ConfigurationException as e:
         raise click.ClickException(e.args[0])
 
@@ -354,6 +362,10 @@ def new(ctx, summary, list, todo_properties, read_description, interactive):
     if default_due:
         todo.due = todo.created_at + timedelta(hours=default_due)
 
+    default_priority = ctx.config['main']['default_priority']
+    if default_priority is not None:
+        todo.priority = default_priority
+
     for key, value in todo_properties.items():
         if value:
             setattr(todo, key, value)
